document.addEventListener('DOMContentLoaded', function() {
  // Tab functionality
  const tabButtons = document.querySelectorAll('.tab-button');
  const tabContents = document.querySelectorAll('.example-content');
  
  tabButtons.forEach(button => {
    button.addEventListener('click', () => {
      // Remove active class from all buttons and contents
      tabButtons.forEach(btn => btn.classList.remove('active'));
      tabContents.forEach(content => content.classList.remove('active'));
      
      // Add active class to clicked button
      button.classList.add('active');
      
      // Show corresponding content
      const tabId = button.getAttribute('data-tab');
      document.getElementById(tabId).classList.add('active');
      
      // Update code examples based on tab
      updateCodeExample(tabId);
    });
  });
  
  // Run button functionality
  const runButton = document.querySelector('.run-button');
  if (runButton) {
    runButton.addEventListener('click', () => {
      runButton.textContent = 'Running...';
      runButton.disabled = true;
      
      // Simulate test running
      setTimeout(() => {
        const output = document.querySelector('.output');
        if (output) {
          output.innerHTML = `
            <div class="test-result">
              <h3>Test Results</h3>
              <div class="test-pass">✓ 14 tests passed</div>
              <div class="test-fail">✗ 1 test failed</div>
              <div class="test-duration">Completed in 1.2s</div>
            </div>
          `;
        }
        
        runButton.textContent = 'Run Tests';
        runButton.disabled = false;
      }, 1500);
    });
  }
  
  // Initialize first tab
  updateCodeExample('unit');
  
  // Smooth scrolling for anchor links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function(e) {
      e.preventDefault();
      
      const targetId = this.getAttribute('href');
      if (targetId === '#') return;
      
      const targetElement = document.querySelector(targetId);
      if (targetElement) {
        targetElement.scrollIntoView({
          behavior: 'smooth'
        });
      }
    });
  });
});

function updateCodeExample(tabId) {
  const codeExample = document.querySelector('.code-example');
  if (!codeExample) return;
  
  let exampleCode = '';
  
  switch(tabId) {
    case 'unit':
      exampleCode = `// Simple unit test example
describe('Math operations', () => {
  test('adds 1 + 2 to equal 3', () => {
    expect(sum(1, 2)).toBe(3);
  });
  
  test('multiplies 3 * 4 to equal 12', () => {
    expect(multiply(3, 4)).toBe(12);
  });
});`;
      break;
    case 'integration':
      exampleCode = `// Integration test example
describe('User API', () => {
  beforeAll(() => setupTestDatabase());
  
  test('creates new user', async () => {
    const response = await request(app)
      .post('/users')
      .send({ name: 'Test', email: 'test@example.com' });
    
    expect(response.status).toBe(201);
    expect(response.body).toHaveProperty('id');
  });
});`;
      break;
    case 'e2e':
      exampleCode = `// End-to-end test example
describe('Login Flow', () => {
  test('successful login', async () => {
    await page.goto('https://example.com/login');
    await page.type('#email', 'user@example.com');
    await page.type('#password', 'password123');
    await page.click('#login-button');
    
    await page.waitForSelector('.dashboard');
    expect(await page.title()).toBe('Dashboard');
  });
});`;
      break;
  }
  
  codeExample.textContent = exampleCode;
}